@@ -64,8 +64,12 @@ MainView* interface_main_view_new( AppData *data ) {
 /*
 	GtkWidget *main_vbox = gtk_vbox_new( FALSE, 0 );
 */
+#if MAEMO_VERSION_MAJOR == 5
+	scrolled_window = hildon_pannable_area_new();
+#else
 	scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#endif
 	result->clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 /* no record window currently showing */
 	result->rec_win=NULL;
